==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_versions/l10n/zh_CN.js <==
OC.L10N.register(
    "files_versions",
    {
    "Versions" : "版本",
    "This application automatically maintains older versions of files that are changed." : "此应用程序自动维护已更改文件的旧版本。",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "此应用程序将会自动保留已被更改的老版本文件。当此应用被启用时，每个用户的目录中都会呈现一个用于版本存储的隐藏文件夹。用户可以随时通过网页将文件恢复到旧版本，替换的文件将作为最新版本。应用程序将自动管理版本文件夹以确保账户不会因保留历史版本耗尽存储空间。\n\t\t除了版本有效期限以外，应用程序会确保保留历史版本的文件不会占用超过账户目前可用空间50%。如果存储的版本超出此限制，则版本管理会先删除最早的版本直至低于存储限制。更多资讯详见“版本”说明文档。",
    "Current version" : "当前版本",
    "Initial version" : "初始版本",
    "Actions for version from {versionHumanExplicitDate}" : "{versionHumanExplicitDate} 版本的操作",
    "Name this version" : "命名此版本",
    "Edit version name" : "编辑版本名",
    "Compare to current version" : "与当前版本比较",
    "Restore version" : "恢复版本",
    "Download version" : "下载版本",
    "Delete version" : "删除版本",
    "Cancel" : "取消",
    "Remove version name" : "删除版本名",
    "Save version name" : "保存版本名",
    "Version name" : "版本名",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "命名版本会保留，且当你的存储配额已满时，它将被从自动清理中排除。",
    "Initial version restored" : "已还原最初版本",
    "Version restored" : "版本已还原",
    "Could not restore version" : "无法还原版本",
    "Could not set version label" : "无法设置版本标签",
    "Could not delete version" : "无法删除版本"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_versions/l10n/zh_CN.js <==
OC.L10N.register(
    "files_versions",
    {
    "Versions" : "版本",
    "This application automatically maintains older versions of files that are changed." : "此应用程序自动维护已更改文件的旧版本。",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "此应用程序将会自动保留已被更改的老版本文件。当此应用被启用时，每个用户的目录中都会呈现一个用于版本存储的隐藏文件夹。用户可以随时通过网页将文件恢复到旧版本，替换的文件将作为最新版本。应用程序将自动管理版本文件夹以确保账户不会因保留历史版本耗尽存储空间。\n\t\t除了版本有效期限以外，应用程序会确保保留历史版本的文件不会占用超过账户目前可用空间50%。如果存储的版本超出此限制，则版本管理会先删除最早的版本直至低于存储限制。更多资讯详见“版本”说明文档。",
    "Current version" : "当前版本",
    "Initial version" : "初始版本",
    "You" : "您",
    "Actions for version from {versionHumanExplicitDate}" : "{versionHumanExplicitDate} 版本的操作",
    "Name this version" : "命名此版本",
    "Edit version name" : "编辑版本名",
    "Compare to current version" : "与当前版本比较",
    "Restore version" : "恢复版本",
    "Download version" : "下载版本",
    "Delete version" : "删除版本",
    "Cancel" : "取消",
    "Remove version name" : "删除版本名",
    "Save version name" : "保存版本名",
    "Version name" : "版本名",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "命名版本会保留，且当你的存储配额已满时，它将被从自动清理中排除。",
    "Initial version restored" : "已还原最初版本",
    "Version restored" : "版本已还原",
    "Could not restore version" : "无法还原版本",
    "Could not set version label" : "无法设置版本标签",
    "Could not delete version" : "无法删除版本",
    "File versions" : "文件版本"
},
"nplurals=1; plural=0;");
